@@ -9,7 +9,7 @@ from jira import JIRA
 def load_json(json_path: str, gitlab_token: str) -> dict:
     if json_path.startswith("https://"):
         gl = gitlab_auth(gitlab_token)
-        file = get_tools_and_databases_json(gl)
+        file = get_gitlab_json(gl, json_path.split("main/")[1])
         return json.loads(file.decode().decode('utf-8'))
     with open(json_path, "r") as json_file:
         return json.load(json_file)
@@ -22,7 +22,7 @@ def save_json(json_path: str, resources_dict: dict):
 
 def save_json_to_gitlab(data: dict, gitlab_token: str):
     gl = gitlab_auth(gitlab_token)
-    file = get_tools_and_databases_json(gl)
+    file = get_gitlab_json(gl, 'json/tools_and_databases.json')
     file.content = json.dumps(data)
     file.save(branch='main', commit_message='Update file')
 
@@ -47,10 +47,10 @@ def gitlab_auth(gitlab_token: str):
     return gl
 
 
-def get_tools_and_databases_json(gl_auth: gitlab.Gitlab):
+def get_gitlab_json(gl_auth: gitlab.Gitlab, file: str):
     project_id = 38164378 # iseqresources Gitlab ID
     project = gl_auth.projects.get(project_id)
-    file = project.files.get(file_path='json/tools_and_databases.json', ref='main')
+    file = project.files.get(file_path=file, ref='main')
     return file
 
 
